function [Z,V,x,r,beta, myPerfMeasure] = GMstab2(A_fun,P,Z,V,x,r,beta,tolabs, myPerfMeasure,xGlobal)
    s                   = size(P,2);
    opts_R.UT           = true;
    opts_L.LT           = true;
    % - - - 1) Compute new basis vectors - - -
    [W,Y,H,Qh,Rh,x,r,beta, myPerfMeasure] ...
                        = augGMRESm(A_fun,P,Z,V(:,:,1),V(:,:,2),x,r(:,1),beta,2*s+2,tolabs, myPerfMeasure,xGlobal);
    if( beta<tolabs )
        return;
    end
    % - - - 2) Biorthogonalise subsequent residual - - -
    gamma               = [beta; zeros(2*s,1) ];
    Qy                  = roworth( Y(:,1:(2*s+1)) );
    Qyh                 = roworth( Y(:,1:(2*s+2)) );
    H0                  = H( 1:(2*s+1),1:(2*s+0));
    Qh0                 = Qh(1:(2*s+1),1:(2*s+0));
    Rh0                 = Rh(1:(2*s+0),1:(2*s+0));
    H1                  = H( 1:(2*s+2),1:(2*s+1));
    H2                  = H( 1:(2*s+3),1:(2*s+2));
    xi                  = linsolve( Rh0, [Qy*Qh0; Qyh*(H1*Qh0)] \ [Qy*gamma; Qyh*(H1*gamma)] );
    c0                  = gamma - H0 * xi;
    c1                  = H1 * c0;
    c2                  = H2 * c1;
    beta                = norm(c0);
    % - - - 3) Polynomial step - - - 
    [tau,beta]          = StabCoeffs([ [c0;0;0] , [c1;0] ,c2 ],beta);
    x                   = x + W(:,1:(2*s+2)) * ( [xi;0;0] + tau(1) * [c0;0] + tau(2) * c1 ) - V(:,:,1) * linsolve(Z, Y(:,1:(2*s))*xi, opts_L);
    % << PerfMeasure
    myPerfMeasure.stop();
    myPerfMeasure.read(xGlobal+x,beta);
    myPerfMeasure.resume();
    % >> PerfMeasure
    if(beta <= tolabs)
        return;
    end
%     if( myPerfMeasure.isTerminate() )
%         return;
%     end
    % - - - 4) Build the next projector - - - 
    % << qr extension of W
    Rw                      = zeros(3*s+3,3*s+3);
    Rw(1:(2*s+3),1:(2*s+3)) = eye(2*s+3,2*s+3);
    for i=1:s
        % orthogonalise V1(:,i) against W(:,j)
        for j=1:(2*s+3)
            Rw(j,2*s+3+i)      	= W(:,j)'   * V(:,i,2);
            V(:,i,2)            = V(:,i,2) - Rw(j      ,2*s+3+i) * W(:,j);
        end
        % orthogonalise V1(:,i) against V1(:,j)
        for j=1:(i-1)
            Rw(2*s+3+j,2*s+3+i)	= V(:,j,2)' * V(:,i,2);
            V(:,i,2)            = V(:,i,2) - Rw(2*s+3+j,2*s+3+i) * V(:,j,2);
        end
        Rw(2*s+3+i,2*s+3+i) = norm( V(:,i,2) );
        V(:,i,2)            = 1/Rw(2*s+3+i,2*s+3+i) * V(:,i,2);
    end
    % >> qr
    Qg                  = nullbasis(H0'*Qy');
    C                   =              [ [H0;zeros(2,2*s  )]    ; zeros(s,2*s)                                  ] ...
                            - tau(1) * [ [H1;zeros(1,2*s+1)]*H0 ; zeros(s,2*s)                                  ] ...
                            - tau(2) * [  H2 * (H1*H0)          ; linsolve( Z, Y(:,1:(2*s+2))*(H1*H0), opts_L ) ];
    F                   = Rw * C * Qg;
    [Qf,Rf]             = qr(F,0);
    [Qz,Lz]             = lq( -tau(2) * (Y(:,1:(2*s+2)) * (H1 * (H0 * (Qg / Rf)))) );
    V(:,:,1)            = [W(:,1:(2*s+2)), V(:,:,1)] ...
                            *(...
                               (             [eye(2*s+2,2*s);-linsolve(Z,Y(:,1:(2*s)),opts_L)] ...
                                 - tau(1) * [   H0;zeros(s+1,2*s)] ...
                                 - tau(2) * [H1*H0;zeros(s  ,2*s)] ...
                                ) * (  Qg * linsolve(Rf, Qz, opts_R)  ) ...
                              );
    V(:,:,2)            = [W(:,1:(2*s+3)), V(:,:,2)] * (Qf*Qz);
    Z                   = Lz;
    r(:,1)              = W * (  [c0;0;0] - tau(1) * [c1;0] - tau(2) * c2  );
end