function [myTestcase] = Testcase09_Norris_torso1_v2()
    
    %% initialise testcase
    myTestcase          = Testcase('Norris\_torso1\_v2');
    sSaveName           = 'Testcase09_Norris_torso1_v2';
    
    %% generate problem instance
    [A_fun,B,X0]        = GenerateLinearSystem();
    [terminate]         = GenerateTermination();
    [param]             = GenerateDefaultParam();
    
    %% 1. System
    myTestcase.pushSystem( A_fun, B(:,1), X0(:,1) );
    myTestcase.setTerminate( terminate );
    myTestcase.setDefaultParam( param );
    % % make solvers for this system
    cGMRES              = makeSolver(myTestcase,'GMRES');
    cIDRbio             = makeSolver(myTestcase,'IDRbiortho');
    cIDRobio            = makeSolver(myTestcase,'IDRobio');
    cIDRstabbio       	= makeSolver(myTestcase,'IDRstabbiortho');
    cIDRstabobio      	= makeSolver(myTestcase,'IDRstabobio');
    cGMstab             = makeSolver(myTestcase,'GMstab');
    
    myTestcase.pushSolver(cGMRES);
    myTestcase.pushSolver(cIDRbio);
    myTestcase.pushSolver(cIDRobio);
    myTestcase.pushSolver(cIDRstabbio);
    myTestcase.pushSolver(cIDRstabobio);
    myTestcase.pushSolver(cGMstab);
    
    %% Run testcase
    myTestcase.Run();
    
    %% Save plot data
    plotData            = myTestcase.getPlotData();
    save(['TestResults/',sSaveName,'_data.mat'],'plotData');
    window_matvec     	= struct('xL',0,'xR',800,'dx',100,'yL',-12,'yR',2,'dy',2);
    window_runtime     	= struct('xL',0,'xR',300,'dx', 20,'yL',-12,'yR',4,'dy',2);
    plot_trueres_over_matvec( plotData,window_matvec, ['TestResults/',sSaveName,'_trueres_matvec.pdf']);
    plot_iterres_over_matvec( plotData,window_matvec, ['TestResults/',sSaveName,'_iterres_matvec.pdf']);
    plot_trueres_over_runtime(plotData,window_runtime,['TestResults/',sSaveName,'_trueres_runtime.pdf']);
    plot_iterres_over_runtime(plotData,window_runtime,['TestResults/',sSaveName,'_iterres_runtime.pdf']);
end

function [A_fun,B,X0]  	= GenerateLinearSystem()
    mydata      = load('C:\Users\Martin\Documents\MATLAB\Studium\MasterArbeit\Solvers\Testproblems\Testcases\_TestSystems\norris_torso1.mat');
    Problem     = mydata.Problem;
    A           = Problem.A;
    s           = symrcm(A);
    A           = A(s,s);
    [L,R]       = ilu(A);
    u           = ones(size(A,1),1);
    b           = A*u;
    b1       	= L\b;
    b1       	= 1/norm(b1) * b1;
    b2        	= L\u;
    b2         	= 1/norm(b2) * b2;
    % generate outputs
    A_fun     	= @(v) L\(A*(R\v));
    B           = [b1,b2];
    X0          = 0*B;
end

function [terminate]    = GenerateTermination()
 	terminate.tolabs            = 1e-10;
    terminate.maxmatvec         = 800;
    terminate.maxruntime        = 300;
end

function [param]        = GenerateDefaultParam()
    param.s  	= 6;
    param.L   	= 2;
end