function [myTestcase] = Testcase17_Ocean_v1()
    
    %% initialise testcase
    myTestcase          = Testcase('Ocean\_v1');
    sSaveName           = 'Testcase17_Ocean_v1';
    
    %% generate problem instance
    [A_fun,B,X0]        = GenerateLinearSystem();
    [terminate]         = GenerateTermination();
    [param]             = GenerateDefaultParam();
    
    %% 1. System
    myTestcase.pushSystem( A_fun, B(:,1), X0(:,1) );
    myTestcase.setTerminate( terminate );
    myTestcase.setDefaultParam( param );
    % % make solvers for this system
    cGMRES              = makeSolver(myTestcase,'GMRES');
    cIDRstabbio       	= makeSolver(myTestcase,'IDRstabbiortho');
    cIDRstabbio.recyclingparam.tolabs2      = 1e-3;
    cGMstab             = makeSolver(myTestcase,'GMstab');
    cGMstab.recyclingparam.tolabs2          = 1e-3;
    
    myTestcase.pushSolver(cGMRES);
    myTestcase.pushSolver(cIDRstabbio);
    myTestcase.pushSolver(cGMstab);
    
    %% 2. System
    myTestcase.pushSystem( A_fun, B(:,2), X0(:,2) );
    myTestcase.setTerminate( terminate );
    myTestcase.setDefaultParam( param );
    % % make solvers for this system
    cIDRstabbio       	= makeSolver(myTestcase,'IDRstabbiortho');
    cIDRstabbio.recyclingparam.systemindex  = 1;
    cIDRstabbio.recyclingparam.solverindex  = 2;
    cGMstab             = makeSolver(myTestcase,'GMstab');
    cGMstab.recyclingparam.systemindex      = 1;
    cGMstab.recyclingparam.solverindex      = 3;
    
    myTestcase.pushSolver(cIDRstabbio);
    myTestcase.pushSolver(cGMstab);
    
    %% Run testcase
    myTestcase.Run();
    
    %% Save plot data
    plotData            = myTestcase.getPlotData();
    save(['TestResults/',sSaveName,'_data.mat'],'plotData');
    window_matvec     	= struct('xL',0,'xR', 800,'dx',100,'yL',-12,'yR',4,'dy',2);
    window_runtime     	= struct('xL',0,'xR',1500,'dx',125,'yL',-12,'yR',4,'dy',2);
    plot_trueres_over_matvec( plotData,window_matvec, ['TestResults/',sSaveName,'_trueres_matvec.pdf']);
    plot_iterres_over_matvec( plotData,window_matvec, ['TestResults/',sSaveName,'_iterres_matvec.pdf']);
    plot_trueres_over_runtime(plotData,window_runtime,['TestResults/',sSaveName,'_trueres_runtime.pdf']);
    plot_iterres_over_runtime(plotData,window_runtime,['TestResults/',sSaveName,'_iterres_runtime.pdf']);
end

function [A_fun,B,X0]  	= GenerateLinearSystem()
    mydata      = load('C:\Users\Martin\Documents\MATLAB\Studium\MasterArbeit\Solvers\Testproblems\Testcases\_TestSystems\Ocean_169850.mat');
    A           = mydata.A;
    L           = mydata.L;
    R           = mydata.R;
    b1          = mydata.b1;
    b2          = mydata.b2;
    b3          = mydata.b3;
    b1       	= L\b1;
    b1       	= 1/norm(b1) * b1;
    b2        	= L\b2;
    b2         	= 1/norm(b2) * b2;
    b3        	= L\b3;
    b3         	= 1/norm(b3) * b3;
    % generate outputs
    A_fun     	= @(v) L\(A*(R\v));
    B           = [b1,b2,b3];
    X0          = 0*B;
end

function [terminate]    = GenerateTermination()
 	terminate.tolabs            = 1e-10;
    terminate.maxmatvec         = 800;
    terminate.maxruntime        = 1500;
end

function [param]        = GenerateDefaultParam()
    param.s  	= 6;
    param.L   	= 2;
end