function [] = plot_iterres_over_runtime(plotData,window,sSaveName)
    
    close all;
    
    %% read data
    string_xlabel   = 'runtime in seconds';
    string_ylabel   = 'relative residual: $\log_{10}\|\textbf{r}^{(\iota\,)}\|/\|\textbf{b}^{(\iota\,)}\|$';
    string_title    = plotData.NameTestcase;
    
    %% set figure
    % % specify size
    cm_inch     = 0.393701;         % 1cm / 1inch
    height      = cm_inch * 9;
    width       = cm_inch * 20;
    myfigure    = figure(   'Units',                'in'                    ,...
                            'Position',             [1 1 width height]      ,...
                            'PaperPositionMode',    'auto'                  );
    set(myfigure,'Units','Inches');
    pos         = get(myfigure,'Position');
    set(myfigure,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)]);
    % % label axes
    xlabel( {string_xlabel} ,...
            'FontUnits',            'points'        ,...
            'interpreter',          'latex'         ,...
            'FontSize',             11              ,...
            'FontName',             'Times'         );
    ylabel( {string_ylabel} ,...
            'FontUnits',            'points'        ,...
            'interpreter',          'latex'         ,...
            'FontSize',             11              ,...
            'FontName',             'Times'         );
    title(  {string_title} ,...
            'FontUnits',            'points'        ,...
            'interpreter',          'latex'         ,...
            'FontSize',             12              ,...
            'FontName',             'Times'         );
    hold all;
    %% make the legend
    % make empty default plots for the legend
    for i=1:length( plotData.listCalls )
        switch plotData.listCalls(i).cSolver.plotparam.Marker
            case ''
                plotData.listCalls(i).cSolver.plotparam.Marker = 'none';
        end
        plot([-100,-100],[-100,-100],                                                            ...
            'LineStyle',            plotData.listCalls(i).cSolver.plotparam.LineStyle          	,...
            'LineWidth',            plotData.listCalls(i).cSolver.plotparam.LineWidth          	,...
            'Color',                plotData.listCalls(i).cSolver.plotparam.Color               ,...
            'Marker',               plotData.listCalls(i).cSolver.plotparam.Marker           	,...
            'MarkerSize',           plotData.listCalls(i).cSolver.plotparam.MarkerSize       	,...
            'MarkerEdgeColor',      plotData.listCalls(i).cSolver.plotparam.MarkerEdgeColor     ,...
            'MarkerFaceColor',      plotData.listCalls(i).cSolver.plotparam.MarkerFaceColor     );
        % prepare legend names
        iota                = plotData.listCalls(i).system_number;
        solverName          = plotData.listCalls(i).out.measure.name;
        solveTime           = max( plotData.listCalls(i).out.measure.runtime );
        float_string        = sprintf('%3.2f',solveTime);
        legend_names{i}     = ['$\iota=',num2str(iota),'$\,:\,',solverName,', ',float_string,'\,sec'];       %#ok<AGROW>
    end
    % set axis
    if(nargin<2)
        xL  = 0;
        xR  = 800;
        dx  = 100;
        yL  = -12;
        yR  = 2;
        dy  = 2;
    else
        xL  = 0;
        xR  = 800;
        dx  = 100;
        yL  = -12;
        yR  = 2;
        dy  = 2;
        if(isfield(window,'xL'))
            xL  = window.xL;
        end
        if(isfield(window,'xR'))
            xR  = window.xR;
        end
        if(isfield(window,'dx'))
            dx  = window.dx;
        end
        if(isfield(window,'xL'))
            yL  = window.yL;
        end
        if(isfield(window,'xL'))
            yR  = window.yR;
        end
        if(isfield(window,'xL'))
            dy  = window.dy;
        end
    end
    % % set axis numbering
    set(    gca,...
            'Units',                'normalized'            ,...
            'YTick',                yL:dy:yR                ,...
            'XTick',                xL:dx:xR                ,...
            'Position',             [0.57/width 0.48/height 1-0.65/width 1-0.82/height]        ,...    % relative position left, bottom, right, top
            'FontUnits',            'points'                ,...
            'FontWeight',           'normal'                ,...
            'FontSize',             11                      ,...
            'FontName',             'Times'                 );
    % set axis intervals
    axis manual
    axis([xL xR yL yR]);
    box on;
    % set legend
    legend(     legend_names                                 	,...
                'FontUnits',                'points'            ,...
                'interpreter',              'latex'             ,...
                'FontSize',                 9                   ,...
                'FontName',                 'Times'             ,...
                'Location',                 'northeastoutside'  );
    
    %% make the plots
    for i=1:length( plotData.listCalls )
        x           = plotData.listCalls(i).out.measure.runtime;
        y           = plotData.listCalls(i).out.measure.iterres;
        y           = log10( y ./ y(1) );
        plot(x,y,                                                                                ...
            'LineStyle',            plotData.listCalls(i).cSolver.plotparam.LineStyle          	,...
            'LineWidth',            plotData.listCalls(i).cSolver.plotparam.LineWidth          	,...
            'Color',                plotData.listCalls(i).cSolver.plotparam.Color               );
        plot(x(1:10:end),y(1:10:end),                                                            ...
            'lineStyle',            'none'                                                      ,...
            'Marker',               plotData.listCalls(i).cSolver.plotparam.Marker           	,...
            'MarkerSize',           plotData.listCalls(i).cSolver.plotparam.MarkerSize       	,...
            'MarkerEdgeColor',      plotData.listCalls(i).cSolver.plotparam.MarkerEdgeColor     ,...
            'MarkerFaceColor',      plotData.listCalls(i).cSolver.plotparam.MarkerFaceColor     );
        if( isfield(plotData.listCalls(i).out.measure,'recycling_index') )
            k           = plotData.listCalls(i).out.measure.recycling_index;
            x           = x(k);
            y           = y(k);
            plot(x,y,                                    ...
                'lineStyle',            'none'      	,...
                'Marker',               'o'           	,...
                'MarkerSize',           10              ,...
                'MarkerEdgeColor',      plotData.listCalls(i).cSolver.plotparam.MarkerEdgeColor     ,...
                'MarkerFaceColor',      'yellow'        );
        end
    end
    
    if(nargin>2)
        print(sSaveName,'-dpdf');
        close all;
    end
    
end